@@ -4,13 +4,9 @@ options(width = 100)
 
 xpdb <- xpdb_ex_pk
 
-knitr::opts_chunk$set(fig.dpi = 96,
-                      fig.align = 'center', 
-                      fig.height = 4, 
-                      fig.width = 4,
-                      out.width = '75%',
-                      comment = '',
-                      message = FALSE)
+knitr::opts_chunk$set(out.width = '75%',
+                      comment   = '',
+                      message   = FALSE)
 
 ## ----demo print xpose_data------------------------------------------------------------------------
 xpdb # or print(xpdb)
